﻿recruitment = LibStub("AceAddon-3.0"):NewAddon("Recruitment")
local L = LibStub("AceLocale-3.0"):GetLocale("Recruitment", true)

local defaults = {
  profile = {
    enabled = true,
		autojoin = true,
		timebetweenads = 5,
		addrandomnumber = true,
		autorandomnumber = true,
		randomnumberrange = 5,
		ads = {},
  }
}

function recruitment:OnInitialize()
	self.db = LibStub("AceDB-3.0"):New("recruitmentdb", defaults, true)
	local options = {
		name = "Recruitment",
		handler = recruitment,
		type = "group",
		childGroups = "tab",
		args = {
			header = {
				order = 10,
				type = "description",
				name = L["Notes"],
				image = "Interface\\Icons\\Achievement_GuildPerk_EverybodysFriend",
				imageWidth = 32,
				imageHeight = 32,
			},
			enabled = {
				order = 20,
				type = "toggle",
				name = L["Enabled"],
				desc = L["EnabledDesc"],
				get = function() return self.db.profile.enabled end,
				set = function(info, value) self.db.profile.enabled = value end,
			},
			generalsettings = {
				order = 30,
				type = "group",
				name = L["GeneralSettings"],
				desc = L["GeneralSettingsHeadline"],
				args = {
					autojoin = {
						order = 10,
						type = "toggle",
						name = L["AutoJoin"],
						desc = L["AutoJoinDesc"],
						width = "full",
						get = function() return self.db.profile.autojoin end,
						set = function() end,
					},
					interval = {
						order = 20,
						type = "range",
						name = L["Interval"],
						desc = L["IntervalDesc1"] .. "\n\n" .. L["IntervalDesc2"],
						width = "full",
						min = 1,
						max = 60,
						step = 1,
						get = function() return self.db.profile.timebetweenads end,
						set = function() end,
					},
					addrandomnumber = {
						order = 30,
						type = "toggle",
						name = L["RandomNumber"],
						desc = L["RandomNumberDesc1"] .. "\n\n" .. L["RandomNumberDesc2"],
						width = "full",
						get = function() return self.db.profile.addrandomnumber end,
						set = function() end,
					},
					autorandomnumber = {
						order = 40,
						type = "toggle",
						name = L["AutoRandomNumber"],
						desc = L["AutoRandomNumberDesc1"] .. "\n\n" .. L["AutoRandomNumberDesc2"] .. "\n\n" .. L["AutoRandomNumberDesc3"],
						width = "full",
						get = function() return self.db.profile.autorandomnumber end,
						set = function() end,
					},
					manualrandomnumber = {
						order = 50,
						type = "range",
						name = L["ManualRandomNumber"],
						desc = L["ManualRandomNumberDesc1"] .. "\n\n" .. L["ManualRandomNumberDesc2"],
						width = "full",
						min = 1,
						max = 60,
						step = 1,
						get = function() return self.db.profile.randomnumberrange end,
						set = function() end,
					},
				},
			},
			ads = {
				order = 40,
				type = "group",
				name = L["Ads"],
				desc = L["AdsHeadline"],
				args = {
					textbox = {
						order = 10,
						type = "input",
						name = L["Ads"],
						desc = L["AdsDesc"],
						width = "full",
						multiline = true,
						get = function() return self.db.profile.ads end,
						set = function() end,
					},
				},
			},
		},
	}
	options.args.profiles = LibStub("AceDBOptions-3.0"):GetOptionsTable(self.db)
	LibStub("AceConfig-3.0"):RegisterOptionsTable("Recruitment", options, nil)
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions("Recruitment")
end

function recruitment:OnEnable()
    -- Called when the addon is enabled
end

function recruitment:OnDisable()
    -- Called when the addon is disabled
end

function recruitment_onload(self)
	self:RegisterEvent("ADDON_LOADED")
	self:RegisterEvent("CHAT_MSG_ADDON")
	self:RegisterEvent("ZONE_CHANGED_NEW_AREA")
	self:RegisterEvent("CHAT_MSG_CHANNEL_NOTICE")
end

local function msg(msg)
	DEFAULT_CHAT_FRAME:AddMessage(msg)
end

local function iscity()
	local zones = {
		L["CityDarnassus"],
		L["CityIronforge"],
		L["CityOrgrimmar"],
		L["CitySilvermoonCity"],
		L["CityStormwindCity"],
		L["CityTheExodar"],
		L["CityThunderBluff"],
		L["CityUndercity"]
	}
	local zonename = GetZoneText()
	for i, v in ipairs(zones) do
		if zonename == v then
			return true
		end
	end
	return false
end

function recruitment_onevent(self, event, ...)
	if event == "ADDON_LOADED" and ... == "Recruitment" then
		self:UnregisterEvent("ADDON_LOADED")
	elseif event == "CHAT_MSG_CHANNEL_NOTICE" then
		local channeljoined, _, _, _, _, _, _, _, channelname = ...
		if channeljoined == "YOU_JOINED" and string.match(channelname, L["GuildRecruitment"]) then
		end
	elseif event == "ZONE_CHANGED_NEW_AREA" then
		if iscity() then
		end
	end
end